==> dative_core-0.0.7.tar.gz: bin/install.dart <==
import 'dart:io';

import 'src/core/bin_run.dart';
import 'src/model/run_model.dart';
import 'src/utils/utils.dart';

Future<void> main(List<String> arguments) async {

  try {

    RunModel? runner = await CoreRunner.installApp(
        purchaseCode: Utils.getPurchaseCode(),
        validationKey: Utils.getValidationKey());

    if(Utils.getGoogleServicesFileAndroid() == null){
      print("Install Error: GoogleServices.json file not found in assets/file folder");
      exit(1);
    }

    if(Utils.getGoogleServicesFileAndroid() != null && !Utils.getGoogleServicesFileAndroid()!.endsWith(".json")){
      print("Install Error: GoogleServices.json is not valid");
      exit(1);
    }

    if(Utils.getGoogleServicesFileIos() == null){
      print("Install Error: GoogleService-Info.plist file not found in assets/file folder");
      exit(1);
    }

    if(Utils.getGoogleServicesFileIos() != null && !Utils.getGoogleServicesFileIos()!.endsWith(".plist")){
      print("Install Error: GoogleService-Info.plist is not valid");
      exit(1);
    }

    if(runner != null){
      Utils.changeAndroidPackageName(runner.package_android);
      Utils.changeIosPackageName(runner.package_ios);
      await Utils.checkSetupInPubspec(packageNameiOS: runner.package_ios);
    }

    await Utils.copyGoogleServicesFilesAndroid(source: Utils.getGoogleServicesFileAndroid());
    await Utils.copyGoogleServicesFilesIos(source: Utils.getGoogleServicesFileIos());

  } catch (e) {
    print('Core Error: $e');
  }
}

==> dative_core-0.0.17.tar.gz: bin/install.dart <==
import 'dart:io';

import 'src/core/bin_run.dart';
import 'src/model/run_model.dart';
import 'src/utils/utils.dart';

Future<void> main(List<String> arguments) async {

  try {

    RunModel? runner = await CoreRunner.installApp(
        purchaseCode: Utils.getPurchaseCode(),
        validationKey: Utils.getValidationKey());

    if(Utils.getGoogleServicesFileAndroid() == null){
      print("Install Error: GoogleServices.json file not found in assets/file folder");
      exit(1);
    }

    if(Utils.getGoogleServicesFileAndroid() != null && !Utils.getGoogleServicesFileAndroid()!.endsWith(".json")){
      print("Install Error: GoogleServices.json is not valid");
      exit(1);
    }

    if(Utils.getGoogleServicesFileIos() == null){
      print("Install Error: GoogleService-Info.plist file not found in assets/file folder");
      exit(1);
    }

    if(Utils.getGoogleServicesFileIos() != null && !Utils.getGoogleServicesFileIos()!.endsWith(".plist")){
      print("Install Error: GoogleService-Info.plist is not valid");
      exit(1);
    }

    if(runner != null){
      Utils.changeAndroidPackageName(runner.package_android);
      Utils.changeIosPackageName(runner.package_ios);
      await Utils.checkSetupInPubspec(packageNameiOS: runner.package_ios, remoteAppName: runner.appName);
    }

    // Commented if we no longer need to copy google services files in android and ios native directories
    await Utils.copyGoogleServicesFilesAndroid(source: Utils.getGoogleServicesFileAndroid());
    await Utils.copyGoogleServicesFilesIos(source: Utils.getGoogleServicesFileIos());

  } catch (e) {
    print('Core Error: $e');
  }
}
